@@ -1,4 +1,4 @@
-# Copyright 2022 Ethan Kinnear
+# Copyright 2023 Olivia Kinnear
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +18,12 @@ from sys import exit
 from pathlib import Path
 from tempfile import mkstemp, mkdtemp
 from typing import TypeVar, NoReturn
-from collections.abc import Iterable, Iterator
+from collections.abc import Iterable, Iterator, Hashable
 
 from click import secho
 
 
-T = TypeVar('T')
+T = TypeVar('T', bound=Hashable)
 
 def unique(items: Iterable[T]) -> Iterator[T]:
     seen = set()
